@@ -21,6 +21,7 @@ from manila_ui.api import manila as api_manila
 from manila_ui.tests.dashboards.project.shares import test_data
 from manila_ui.tests import helpers as test
 
+from openstack_dashboard.api import base
 from openstack_dashboard.api import neutron
 from openstack_dashboard.api import nova
 from openstack_dashboard.usage import quotas
@@ -28,6 +29,19 @@ from openstack_dashboard.usage import quotas
 SHARE_INDEX_URL = reverse('horizon:project:shares:index')
 
 
+class QuotaTests(test.TestCase):
+
+    def test_get_disabled_quotas(self):
+        self.mock_object(
+            base, "is_service_enabled", mock.Mock(return_value=False))
+
+        result_quotas = quotas.get_disabled_quotas(self.request)
+        expected_quotas = set(
+            quotas.QUOTA_FIELDS + quotas.MISSING_QUOTA_FIELDS)
+
+        self.assertItemsEqual(result_quotas, expected_quotas)
+
+
 @ddt.ddt
 class ShareViewTests(test.TestCase):
 
@@ -49,6 +63,7 @@ class ShareViewTests(test.TestCase):
     @mock.patch.object(nova, 'availability_zone_list')
     def test_create_share(self, az_list):
         url = reverse('horizon:project:shares:create')
+        share = test_data.share
         share_net = test_data.active_share_network
         share_nets = [share_net]
         formData = {
@@ -64,7 +79,8 @@ class ShareViewTests(test.TestCase):
         }
 
         az_list.return_value = [self.FakeAZ('fake_az'), ]
-        self.mock_object(api_manila, "share_create")
+        self.mock_object(
+            api_manila, "share_create", mock.Mock(return_value=share))
         self.mock_object(
             api_manila, "share_snapshot_list", mock.Mock(return_value=[]))
         self.mock_object(
@@ -88,6 +104,7 @@ class ShareViewTests(test.TestCase):
 
     @mock.patch.object(nova, 'availability_zone_list')
     def test_create_share_from_snapshot(self, mock_az_list):
+        share = test_data.share
         share_net = test_data.active_share_network
         share_nets = [share_net]
         snapshot = test_data.snapshot
@@ -106,7 +123,8 @@ class ShareViewTests(test.TestCase):
             'availability_zone': 'fake_az',
         }
         mock_az_list.return_value = [self.FakeAZ('fake_az'), ]
-        self.mock_object(api_manila, "share_create")
+        self.mock_object(
+            api_manila, "share_create", mock.Mock(return_value=share))
         self.mock_object(
             api_manila, "share_snapshot_list",
             mock.Mock(return_value=[snapshot]))
@@ -207,8 +225,6 @@ class ShareViewTests(test.TestCase):
     def test_update_share_get(self):
         share = test_data.share
         url = reverse('horizon:project:shares:update', args=[share.id])
-        self.mock_object(
-            api_manila, "share_get", mock.Mock(return_value=share))
         self.mock_object(
             neutron, "is_service_enabled", mock.Mock(return_value=[True]))
 
@@ -310,8 +326,6 @@ class ShareViewTests(test.TestCase):
         url = reverse('horizon:project:shares:extend', args=[share.id])
         self.mock_object(
             quotas, "tenant_limit_usages", mock.Mock(return_value=usage_limit))
-        self.mock_object(
-            api_manila, "share_get", mock.Mock(return_value=share))
         self.mock_object(
             neutron, "is_service_enabled", mock.Mock(return_value=[True]))
 
@@ -410,10 +424,7 @@ class ShareViewTests(test.TestCase):
         self.assertTemplateUsed(response, 'project/shares/shares/extend.html')
         self.assertFalse(api_manila.share_extend.called)
         api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
-        if new_size <= self.share.size:
-            self.assertFalse(quotas.tenant_limit_usages.called)
-        else:
-            quotas.tenant_limit_usages.assert_called_once_with(mock.ANY)
+        quotas.tenant_limit_usages.assert_called_with(mock.ANY)
         self.assertEqual(3, neutron.is_service_enabled.call_count)
 
     def test_extend_share_post_with_api_exception(self):
@@ -440,3 +451,41 @@ class ShareViewTests(test.TestCase):
         api_manila.share_get.assert_called_once_with(mock.ANY, self.share.id)
         quotas.tenant_limit_usages.assert_called_once_with(mock.ANY)
         self.assertRedirectsNoFollow(response, SHARE_INDEX_URL)
+
+    def test_update_share_metadata_get(self):
+        share = test_data.share_with_metadata
+        url = reverse(
+            'horizon:project:shares:update_metadata', args=[share.id])
+        self.mock_object(
+            api_manila, "share_get", mock.Mock(return_value=share))
+        self.mock_object(
+            neutron, "is_service_enabled", mock.Mock(return_value=[True]))
+
+        res = self.client.get(url)
+
+        api_manila.share_get.assert_called_once_with(mock.ANY, share.id)
+        self.assertNoMessages()
+        self.assertTemplateUsed(
+            res, 'project/shares/shares/update_metadata.html')
+
+    def test_update_share_metadata_post(self):
+        share = test_data.share_with_metadata
+        data = {
+            'metadata': 'aaa=ccc',
+        }
+        form_data = {
+            'metadata': {'aaa': 'ccc'},
+        }
+        url = reverse(
+            'horizon:project:shares:update_metadata', args=[share.id])
+        self.mock_object(
+            api_manila, "share_get", mock.Mock(return_value=share))
+        self.mock_object(api_manila, "share_set_metadata")
+        self.mock_object(
+            neutron, "is_service_enabled", mock.Mock(return_value=[True]))
+
+        res = self.client.post(url, data)
+
+        api_manila.share_set_metadata.assert_called_once_with(
+            mock.ANY, share, form_data['metadata'])
+        self.assertRedirectsNoFollow(res, SHARE_INDEX_URL)
